@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 #--------------------------------------------------------------------------
 
@@ -52,8 +52,8 @@ use constant	LB2G    => 453.59237;   # number of grams in a pound (lb)
 
 =item C<search()>
 
-Creates a query string, then passes the appropriate form fields to the A1Books
-server.
+Creates a query string, then passes the appropriate form fields to the 
+A1Books server.
 
 The returned page should be the correct catalog page for that ISBN. If not the
 function returns zero and allows the next driver in the chain to have a go. If
